@@ -31,12 +31,15 @@ from ._pygit2 import *
 
 # High level API
 from .blame import Blame, BlameHunk
+from .blob import BlobIO
 from .callbacks import git_clone_options, git_fetch_options, get_credentials
 from .callbacks import Payload, RemoteCallbacks, CheckoutCallbacks, StashApplyCallbacks
 from .config import Config
 from .credentials import *
 from .errors import check_error, Passthrough
+from .enums import SubmoduleIgnore, SubmoduleStatus
 from .ffi import ffi, C
+from .filter import Filter
 from .index import Index, IndexEntry
 from .remote import Remote
 from .repository import Repository
@@ -92,6 +95,8 @@ GIT_ATTR_CHECK_FILE_THEN_INDEX = C.GIT_ATTR_CHECK_FILE_THEN_INDEX
 GIT_ATTR_CHECK_INDEX_THEN_FILE = C.GIT_ATTR_CHECK_INDEX_THEN_FILE
 GIT_ATTR_CHECK_INDEX_ONLY      = C.GIT_ATTR_CHECK_INDEX_ONLY
 GIT_ATTR_CHECK_NO_SYSTEM       = C.GIT_ATTR_CHECK_NO_SYSTEM
+GIT_ATTR_CHECK_INCLUDE_HEAD    = C.GIT_ATTR_CHECK_INCLUDE_HEAD
+GIT_ATTR_CHECK_INCLUDE_COMMIT  = C.GIT_ATTR_CHECK_INCLUDE_COMMIT
 
 # GIT_FETCH_PRUNE
 GIT_FETCH_PRUNE_UNSPECIFIED    = C.GIT_FETCH_PRUNE_UNSPECIFIED
@@ -197,7 +202,7 @@ def init_repository(path, bare=False,
 
 def clone_repository(
         url, path, bare=False, repository=None, remote=None,
-        checkout_branch=None, callbacks=None):
+        checkout_branch=None, callbacks=None, depth=0):
     """
     Clones a new Git repository from *url* in the given *path*.
 
@@ -231,6 +236,12 @@ def clone_repository(
 
         The callbacks should be an object which inherits from
         `pyclass:RemoteCallbacks`.
+    depth : int
+        Number of commits to clone.
+
+        If greater than 0, creates a shallow clone with a history truncated to
+        the specified number of commits.
+        The default is 0 (full commit history).
     """
 
     if callbacks is None:
@@ -244,6 +255,7 @@ def clone_repository(
     with git_clone_options(payload):
         opts = payload.clone_options
         opts.bare = bare
+        opts.fetch_opts.depth = depth
 
         if checkout_branch:
             checkout_branch_ref = ffi.new('char []', to_bytes(checkout_branch))
